@@ -1,4 +1,5 @@
 import argparse
+from typing import Optional
 
 import annofabcli
 import annofabcli.annotation.change_annotation_attributes
@@ -25,7 +26,7 @@ def parse_args(parser: argparse.ArgumentParser):
     annofabcli.annotation.restore_anotation.add_parser(subparsers)
 
 
-def add_parser(subparsers: argparse._SubParsersAction):
+def add_parser(subparsers: Optional[argparse._SubParsersAction] = None) -> argparse.ArgumentParser:
     subcommand_name = "annotation"
     subcommand_help = "アノテーション関係のサブコマンド"
     description = "アノテーション関係のサブコマンド"
@@ -34,3 +35,4 @@ def add_parser(subparsers: argparse._SubParsersAction):
         subparsers, subcommand_name, subcommand_help, description, is_subcommand=False
     )
     parse_args(parser)
+    return parser
