@@ -1,4 +1,5 @@
 import argparse
+from typing import Optional
 
 import annofabcli
 import annofabcli.common.cli
@@ -23,7 +24,7 @@ def parse_args(parser: argparse.ArgumentParser):
     annofabcli.project.update_annotation_zip.add_parser(subparsers)
 
 
-def add_parser(subparsers: argparse._SubParsersAction):
+def add_parser(subparsers: Optional[argparse._SubParsersAction] = None):
     subcommand_name = "project"
     subcommand_help = "プロジェクト関係のサブコマンド"
     description = "プロジェクト関係のサブコマンド"
@@ -32,3 +33,4 @@ def add_parser(subparsers: argparse._SubParsersAction):
         subparsers, subcommand_name, subcommand_help, description, is_subcommand=False
     )
     parse_args(parser)
+    return parser
