@@ -1,5 +1,6 @@
 import logging
 import math
+from enum import Enum
 from pathlib import Path
 from typing import Any, List, Optional, Sequence, Tuple
 
@@ -15,6 +16,15 @@ from bokeh.plotting import ColumnDataSource, figure
 logger = logging.getLogger(__name__)
 
 
+class WorktimeType(Enum):
+    """
+    作業時間の種類
+    """
+
+    ACTUAL = "actual"
+    MONITORED = "monitored"
+
+
 class Scatter:
     """
     散布図を出力するクラス
@@ -69,7 +79,7 @@ class Scatter:
             tmp = name.split("_")
             return "_".join(tmp[0 : len(tmp) - 1])
 
-        detail_tooltips = [(exclude_phase_name(e), "@{%s}" % e) for e in tool_tip_items]
+        detail_tooltips = [(exclude_phase_name(e), f"@{{{e}}}") for e in tool_tip_items]
         hover_tool = HoverTool(tooltips=detail_tooltips)
         return hover_tool
 
@@ -240,17 +250,10 @@ class Scatter:
             """
         )
 
-    def write_scatter_for_productivity_by_monitored_worktime(self, df: pandas.DataFrame):
-        """
-        AnnoFab計測時間を元に算出した生産性を、メンバごとにプロットする
-
-        Args:
-            df:
-            first_annotation_user_id_list: 最初のアノテーションを担当したuser_idのList. Noneの場合はtask_dfから決まる。
-
-        Returns:
-
-        """
+    def _write_scatter_for_productivity_by_monitored_worktime(self, df: pandas.DataFrame, worktime_type: WorktimeType):
+        """作業時間と生産性の関係をメンバごとにプロットする。"""
+        # numpy.inf が含まれていると散布図を出力できないので置換する
+        df = df.replace(numpy.inf, numpy.nan)
 
         def create_figure(title: str) -> bokeh.plotting.Figure:
             return figure(
@@ -261,20 +264,28 @@ class Scatter:
                 y_axis_label="アノテーションあたり作業時間[hour/annotation]",
             )
 
-        html_title = "散布図-アノテーションあたり作業時間と累計作業時間の関係-計測時間"
+        if worktime_type == WorktimeType.ACTUAL:
+            worktime_name = "実績時間"
+            worktime_key_for_phase = "prediction_actual"
+        elif worktime_type == WorktimeType.MONITORED:
+            worktime_name = "計測時間"
+            worktime_key_for_phase = WorktimeType.MONITORED.value
+
+        html_title = f"散布図-アノテーションあたり作業時間と累計作業時間の関係-{worktime_name}"
         output_file = f"{self.scatter_outdir}/{html_title}.html"
         logger.debug(f"{output_file} を出力します。")
 
         phase_list = self._get_phase_list(df)
         figure_list = [
-            create_figure(f"{self.dict_phase_name[phase]}のアノテーションあたり作業時間と累計作業時間の関係(計測時間)") for phase in phase_list
+            create_figure(f"{self.dict_phase_name[phase]}のアノテーションあたり作業時間と累計作業時間の関係({worktime_name})")
+            for phase in phase_list
         ]
 
         df["biography"] = df["biography"].fillna("")
 
-        for biography_index, biography in enumerate(set(df["biography"])):
-            x_column = "monitored_worktime_hour"
-            y_column = "monitored_worktime/annotation_count"
+        for biography_index, biography in enumerate(sorted(set(df["biography"]))):
+            x_column = f"{worktime_key_for_phase}_worktime_hour"
+            y_column = f"{worktime_type.value}_worktime/annotation_count"
             for fig, phase in zip(figure_list, phase_list):
                 filtered_df = df[
                     (df["biography"] == biography) & df[(x_column, phase)].notna() & df[(y_column, phase)].notna()
@@ -294,11 +305,11 @@ class Scatter:
         for fig, phase in zip(figure_list, phase_list):
             average_value = self._get_average_value(
                 df,
-                numerator_column=("monitored_worktime_hour", phase),
+                numerator_column=(f"{worktime_key_for_phase}_worktime_hour", phase),
                 denominator_column=("annotation_count", phase),
             )
             self._plot_average_line(fig, average_value, dimension="width")
-            quartile = self._get_quartile_value(df, ("monitored_worktime/annotation_count", phase))
+            quartile = self._get_quartile_value(df, (f"{worktime_type.value}_worktime/annotation_count", phase))
             self._plot_quartile_line(fig, quartile, dimension="width")
 
         for fig, phase in zip(figure_list, phase_list):
@@ -306,15 +317,16 @@ class Scatter:
                 "user_id_",
                 "username_",
                 "biography_",
-                "last_working_date_",
-                f"monitored_worktime_hour_{phase}",
+                f"{worktime_key_for_phase}_worktime_hour_{phase}",
                 f"task_count_{phase}",
                 f"input_data_count_{phase}",
                 f"annotation_count_{phase}",
-                f"prediction_actual_worktime_hour_{phase}",
-                f"monitored_worktime/input_data_count_{phase}",
-                f"monitored_worktime/annotation_count_{phase}",
+                f"{worktime_key_for_phase}_worktime/input_data_count_{phase}",
+                f"{worktime_key_for_phase}_worktime/annotation_count_{phase}",
             ]
+            if worktime_type == WorktimeType.ACTUAL:
+                tooltip_item.append("last_working_date_")
+
             hover_tool = self._create_hover_tool(tooltip_item)
             fig.add_tools(hover_tool)
             self._set_legend(fig)
@@ -324,87 +336,17 @@ class Scatter:
         bokeh.plotting.output_file(output_file, title=html_title)
         bokeh.plotting.save(bokeh.layouts.column([div_element] + figure_list))
 
+    def write_scatter_for_productivity_by_monitored_worktime(self, df: pandas.DataFrame):
+        """
+        AnnoFab計測時間とAnnoFab計測時間を元に算出した生産性を、メンバごとにプロットする
+        """
+        self._write_scatter_for_productivity_by_monitored_worktime(df, worktime_type=WorktimeType.MONITORED)
+
     def write_scatter_for_productivity_by_actual_worktime(self, df: pandas.DataFrame):
         """
-        実績作業時間を元に算出した生産性を、メンバごとにプロットする
-
-        Args:
-            df:
-        Returns:
-
+        実績作業時間と実績作業時間を元に算出した生産性を、メンバごとにプロットする
         """
-
-        def create_figure(title: str) -> bokeh.plotting.Figure:
-            return figure(
-                plot_width=1200,
-                plot_height=800,
-                title=title,
-                x_axis_label="累計作業時間[hour]",
-                y_axis_label="アノテーションあたり作業時間[hour/annotation]",
-            )
-
-        html_title = "散布図-アノテーションあたり作業時間と累計作業時間の関係-実績時間"
-        output_file = f"{self.scatter_outdir}/{html_title}.html"
-        logger.debug(f"{output_file} を出力します。")
-
-        phase_list = self._get_phase_list(df)
-        figure_list = [
-            create_figure(f"{self.dict_phase_name[phase]}のアノテーションあたり作業時間と累計作業時間の関係(実績時間)") for phase in phase_list
-        ]
-
-        df["biography"] = df["biography"].fillna("")
-        for biography_index, biography in enumerate(set(df["biography"])):
-            x_column = "prediction_actual_worktime_hour"
-            y_column = "actual_worktime/annotation_count"
-            for fig, phase in zip(figure_list, phase_list):
-                filtered_df = df[
-                    (df["biography"] == biography) & df[(x_column, phase)].notna() & df[(y_column, phase)].notna()
-                ]
-                if len(filtered_df) == 0:
-                    continue
-                source = ColumnDataSource(data=filtered_df)
-                self._scatter(
-                    fig=fig,
-                    source=source,
-                    x_column_name=f"{x_column}_{phase}",
-                    y_column_name=f"{y_column}_{phase}",
-                    legend_label=biography,
-                    color=self.my_palette[biography_index],
-                )
-
-        for fig, phase in zip(figure_list, phase_list):
-            average_value = self._get_average_value(
-                df,
-                numerator_column=("prediction_actual_worktime_hour", phase),
-                denominator_column=("annotation_count", phase),
-            )
-            self._plot_average_line(fig, average_value, dimension="width")
-
-            quartile = self._get_quartile_value(df, ("actual_worktime/annotation_count", phase))
-            self._plot_quartile_line(fig, quartile, dimension="width")
-
-        for fig, phase in zip(figure_list, phase_list):
-            tooltip_item = [
-                "user_id_",
-                "username_",
-                "biography_",
-                "last_working_date_",
-                f"prediction_actual_worktime_hour_{phase}",
-                f"task_count_{phase}",
-                f"input_data_count_{phase}",
-                f"annotation_count_{phase}",
-                f"monitored_worktime_hour_{phase}",
-                f"actual_worktime/input_data_count_{phase}",
-                f"actual_worktime/annotation_count_{phase}",
-            ]
-            hover_tool = self._create_hover_tool(tooltip_item)
-            fig.add_tools(hover_tool)
-            self._set_legend(fig)
-
-        div_element = self._create_div_element()
-        bokeh.plotting.reset_output()
-        bokeh.plotting.output_file(output_file, title=html_title)
-        bokeh.plotting.save(bokeh.layouts.column([div_element] + figure_list))
+        self._write_scatter_for_productivity_by_monitored_worktime(df, worktime_type=WorktimeType.ACTUAL)
 
     def write_scatter_for_quality(self, df: pandas.DataFrame):
         """
@@ -415,6 +357,8 @@ class Scatter:
         Returns:
 
         """
+        # numpy.inf が含まれていると散布図を出力できないので置換する
+        df = df.replace(numpy.inf, numpy.nan)
 
         def create_figure(title: str, x_axis_label: str, y_axis_label: str) -> bokeh.plotting.Figure:
             return figure(
@@ -443,7 +387,7 @@ class Scatter:
         phase = "annotation"
 
         df["biography"] = df["biography"].fillna("")
-        for biography_index, biography in enumerate(set(df["biography"])):
+        for biography_index, biography in enumerate(sorted(set(df["biography"]))):
             for column_pair, fig in zip(column_pair_list, figure_list):
                 x_column = column_pair[0]
                 y_column = column_pair[1]
@@ -508,6 +452,29 @@ class Scatter:
         """
         実績作業時間を元に算出した生産性と品質の関係を、メンバごとにプロットする
         """
+        self._write_scatter_for_productivity_by_worktime_and_quality(df, worktime_type=WorktimeType.ACTUAL)
+
+    def write_scatter_for_productivity_by_monitored_worktime_and_quality(self, df: pandas.DataFrame):
+        """
+        計測作業時間を元に算出した生産性と品質の関係を、メンバごとにプロットする
+        """
+        self._write_scatter_for_productivity_by_worktime_and_quality(df, worktime_type=WorktimeType.MONITORED)
+
+    def _write_scatter_for_productivity_by_worktime_and_quality(
+        self, df: pandas.DataFrame, worktime_type: WorktimeType
+    ):
+        """
+        作業時間を元に算出した生産性と品質の関係を、メンバごとにプロットする
+        """
+        if worktime_type == WorktimeType.ACTUAL:
+            worktime_name = "実績時間"
+            worktime_key_for_phase = "prediction_actual"
+        elif worktime_type == WorktimeType.MONITORED:
+            worktime_name = "計測時間"
+            worktime_key_for_phase = WorktimeType.MONITORED.value
+
+        # numpy.inf が含まれていると散布図を出力できないので置換する
+        df = df.replace(numpy.inf, numpy.nan)
 
         def create_figure(title: str, x_axis_label: str, y_axis_label: str) -> bokeh.plotting.Figure:
             return figure(
@@ -518,7 +485,7 @@ class Scatter:
                 y_axis_label=y_axis_label,
             )
 
-        html_title = "散布図-アノテーションあたり作業時間と品質の関係-実績時間-教師付者用"
+        html_title = f"散布図-アノテーションあたり作業時間と品質の関係-{worktime_name}-教師付者用"
         output_file = f"{self.scatter_outdir}/{html_title}.html"
         logger.debug(f"{output_file} を出力します。")
 
@@ -533,12 +500,15 @@ class Scatter:
             ),
         ]
         column_pair_list = [
-            ("actual_worktime/annotation_count", "rejected_count/task_count"),
-            ("actual_worktime/annotation_count", "pointed_out_inspection_comment_count/annotation_count"),
+            (f"{worktime_type.value}_worktime/annotation_count", "rejected_count/task_count"),
+            (
+                f"{worktime_type.value}_worktime/annotation_count",
+                "pointed_out_inspection_comment_count/annotation_count",
+            ),
         ]
         phase = TaskPhase.ANNOTATION.value
         df["biography"] = df["biography"].fillna("")
-        for biography_index, biography in enumerate(set(df["biography"])):
+        for biography_index, biography in enumerate(sorted(set(df["biography"]))):
             for fig, column_pair in zip(figure_list, column_pair_list):
                 x_column, y_column = column_pair
                 filtered_df = df[
@@ -552,14 +522,14 @@ class Scatter:
                     source=source,
                     x_column_name=f"{x_column}_{phase}",
                     y_column_name=f"{y_column}_{phase}",
-                    size_column_name=f"prediction_actual_worktime_hour_{phase}",
+                    size_column_name=f"{worktime_key_for_phase}_worktime_hour_{phase}",
                     legend_label=biography,
                     color=self.my_palette[biography_index],
                 )
 
         x_average_value = self._get_average_value(
             df,
-            numerator_column=("prediction_actual_worktime_hour", phase),
+            numerator_column=(f"{worktime_key_for_phase}_worktime_hour", phase),
             denominator_column=("annotation_count", phase),
         )
         for column_pair, fig in zip(
@@ -574,7 +544,7 @@ class Scatter:
             )
             self._plot_average_line(fig, y_average_value, dimension="width")
 
-        x_quartile = self._get_quartile_value(df, ("actual_worktime/annotation_count", phase))
+        x_quartile = self._get_quartile_value(df, (f"{worktime_type.value}_worktime/annotation_count", phase))
         for column, fig in zip(
             ["rejected_count/task_count", "pointed_out_inspection_comment_count/annotation_count"],
             figure_list,
@@ -588,25 +558,26 @@ class Scatter:
                 "user_id_",
                 "username_",
                 "biography_",
-                "last_working_date_",
-                f"prediction_actual_worktime_hour_{phase}",
+                f"{worktime_key_for_phase}_worktime_hour_{phase}",
                 f"task_count_{phase}",
                 f"input_data_count_{phase}",
                 f"annotation_count_{phase}",
-                f"monitored_worktime_hour_{phase}",
-                f"actual_worktime/input_data_count_{phase}",
-                f"actual_worktime/annotation_count_{phase}",
+                f"{worktime_type.value}_worktime/input_data_count_{phase}",
+                f"{worktime_type.value}_worktime/annotation_count_{phase}",
                 f"rejected_count_{phase}",
                 f"pointed_out_inspection_comment_count_{phase}",
                 f"rejected_count/task_count_{phase}",
                 f"pointed_out_inspection_comment_count/annotation_count_{phase}",
             ]
+            if worktime_type == WorktimeType.ACTUAL:
+                tooltip_item.append("last_working_date_")
+
             hover_tool = self._create_hover_tool(tooltip_item)
             fig.add_tools(hover_tool)
             self._set_legend(fig)
 
         div_element = self._create_div_element()
-        div_element.text += """円の大きさ：実績作業時間（prediction_actual_worktime_hour）<br>"""
+        div_element.text += """円の大きさ：作業時間<br>"""
         bokeh.plotting.reset_output()
         bokeh.plotting.output_file(output_file, title=html_title)
         bokeh.plotting.save(bokeh.layouts.column([div_element] + figure_list))
